@@ -1,6 +1,6 @@
 # Encoding: UTF-8
 
 from compositry.tasks import Task
-from compositry import stores
+from compositry import state
 
-__version__ = "0.3.0"
+__version__ = "0.4.0"
